Blender Git Commit Log

All Blender Git commits.

Page: 3750 / 8462

August 3, 2017, 06:00 (GMT)
Merge branch 'master' of git.blender.org:blender into soc-2017-package_manager
August 3, 2017, 05:05 (GMT)
Manipulator: Use 2D manipulators in the 3D view

Also split update flag into draw-steps,
since drawing 3D manipulators was tagging 2D as being refreshed.
August 3, 2017, 01:21 (GMT)
Manipulator: use default for cage2d dimensions

Also minor cleanuup, assign new vars for manipulator group.
August 2, 2017, 22:20 (GMT)
Cleanup: split 3D view manipulators by type
August 2, 2017, 21:59 (GMT)
Cleanup: rename selectionbase -> select_id
August 2, 2017, 21:59 (GMT)
Cleanup: warnings
August 2, 2017, 21:35 (GMT)
Default settings for hair edit mode tool settings.
August 2, 2017, 21:28 (GMT)
Disable selection outline drawing on the object during hair edit mode.
August 2, 2017, 21:10 (GMT)
Merge branch 'master' into blender2.8
August 2, 2017, 21:03 (GMT)
mikktspace: minor optimization

Add a safe version of normalize since all uses of normalize
did zero length checks, move this into a function.

Also avoid unnecessary conversion.

Gives minor speedup here (approx 3-5%).
August 2, 2017, 21:03 (GMT)
Remove volatile, causing issues w/ GCC/ubsan

Was Cygwin workaround, no longer needed.
August 2, 2017, 20:54 (GMT)
Removed leftover hair fiber code from edit mode drawing (all in Eevee now).
August 2, 2017, 20:40 (GMT)
Moved the hair fiber shader from strand edit mode into Eevee.

This allows the shader to use proper lighting from the standard Eevee shaders.

The code for interpolating hair strands is in a glsl library file to facilitate
use in other engines later.
August 2, 2017, 18:59 (GMT)
Cycles: Avoid some expensive operations in header expansions

Basically gather lines as-is during traversal, avoiding allocating
memory for all the lines in headers.

Brings additional performance improvement abut 20%.
August 2, 2017, 18:59 (GMT)
Cycles: Support "precompiled" headers in include expansion algorithm

The idea here is that it is possible to mark certain include statements
as "precompiled" which means all subsequent includes of that file will
be replaced with an empty string.

This is a way to deal with tricky include pattern happening in single
program OpenCL split kernel which was including bunch of headers about
10 times.

This brings preprocessing time from ~1sec to ~0.1sec on my laptop.
August 2, 2017, 18:59 (GMT)
Cycles: Speed up #include expansion algorithm

The idea is to re-use files which were already processed. Gives about 4x speedup
of processing time (~4.5sec vs 1.0sec) on my laptop for the whole OpenCL kernel.

For users it will mean lower delay before OpenCL rendering might start.
August 2, 2017, 14:46 (GMT)
Fix T52250: Glitch in UI in the addon panel regression
August 2, 2017, 13:52 (GMT)
GraphEdit Handle Drawing: Fix handle-vertex size regression (2.7 -> 2.8)

Keyframe handle vertices (the circles on the ends of the handles)
should always be larger than the central vertex. This brings back the
"outer" radius value from the old gluDisk(), and doubles it to get the
necessary diameter, to scale it properly.

TODO's:
- Get rid of all fills inside these circles
- Make the central vertex square-shaped again
August 2, 2017, 13:25 (GMT)
Keyframe Drawing: Fix 2.7 -> 2.8 regressions

* Outlines of keyframes were too thick and ugly

* Size differences between keyframe types was being swallowed
by the pixel-fudge factor, leaving colour as the only distinguishing
factor (bad!)
August 2, 2017, 10:25 (GMT)
new color layor set to default rather tha copying previos one
By: Miika HämäläinenLast update: Nov-07-2014 14:18MiikaHweb | 2003-2021